@@ -17,6 +17,7 @@ class AlipayBusinessOrderOrderinfoSyncModel(object):
         self._contact = None
         self._discount_amount = None
         self._ext_info = None
+        self._open_id = None
         self._order_character = None
         self._order_create_time = None
         self._order_id = None
@@ -93,6 +94,13 @@ class AlipayBusinessOrderOrderinfoSyncModel(object):
                 else:
                     self._ext_info.append(ScenicExtInfo.from_alipay_dict(i))
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def order_character(self):
         return self._order_character
 
@@ -332,6 +340,11 @@ class AlipayBusinessOrderOrderinfoSyncModel(object):
                 params['ext_info'] = self.ext_info.to_alipay_dict()
             else:
                 params['ext_info'] = self.ext_info
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.order_character:
             if hasattr(self.order_character, 'to_alipay_dict'):
                 params['order_character'] = self.order_character.to_alipay_dict()
@@ -494,6 +507,8 @@ class AlipayBusinessOrderOrderinfoSyncModel(object):
             o.discount_amount = d['discount_amount']
         if 'ext_info' in d:
             o.ext_info = d['ext_info']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'order_character' in d:
             o.order_character = d['order_character']
         if 'order_create_time' in d:
