@@ -8,6 +8,7 @@ from alipay.aop.api.constant.ParamConstants import *
 class AlipayCommerceEcEmployeeInfoModifyModel(object):
 
     def __init__(self):
+        self._accounting_entity_ids = None
         self._department_ids = None
         self._employee_email = None
         self._employee_id = None
@@ -15,9 +16,21 @@ class AlipayCommerceEcEmployeeInfoModifyModel(object):
         self._employee_name = None
         self._employee_no = None
         self._enterprise_id = None
+        self._label_names = None
+        self._profiles = None
         self._role_list = None
 
     @property
+    def accounting_entity_ids(self):
+        return self._accounting_entity_ids
+
+    @accounting_entity_ids.setter
+    def accounting_entity_ids(self, value):
+        if isinstance(value, list):
+            self._accounting_entity_ids = list()
+            for i in value:
+                self._accounting_entity_ids.append(i)
+    @property
     def department_ids(self):
         return self._department_ids
 
@@ -70,6 +83,23 @@ class AlipayCommerceEcEmployeeInfoModifyModel(object):
     def enterprise_id(self, value):
         self._enterprise_id = value
     @property
+    def label_names(self):
+        return self._label_names
+
+    @label_names.setter
+    def label_names(self, value):
+        if isinstance(value, list):
+            self._label_names = list()
+            for i in value:
+                self._label_names.append(i)
+    @property
+    def profiles(self):
+        return self._profiles
+
+    @profiles.setter
+    def profiles(self, value):
+        self._profiles = value
+    @property
     def role_list(self):
         return self._role_list
 
@@ -83,6 +113,16 @@ class AlipayCommerceEcEmployeeInfoModifyModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.accounting_entity_ids:
+            if isinstance(self.accounting_entity_ids, list):
+                for i in range(0, len(self.accounting_entity_ids)):
+                    element = self.accounting_entity_ids[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.accounting_entity_ids[i] = element.to_alipay_dict()
+            if hasattr(self.accounting_entity_ids, 'to_alipay_dict'):
+                params['accounting_entity_ids'] = self.accounting_entity_ids.to_alipay_dict()
+            else:
+                params['accounting_entity_ids'] = self.accounting_entity_ids
         if self.department_ids:
             if isinstance(self.department_ids, list):
                 for i in range(0, len(self.department_ids)):
@@ -123,6 +163,21 @@ class AlipayCommerceEcEmployeeInfoModifyModel(object):
                 params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
             else:
                 params['enterprise_id'] = self.enterprise_id
+        if self.label_names:
+            if isinstance(self.label_names, list):
+                for i in range(0, len(self.label_names)):
+                    element = self.label_names[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.label_names[i] = element.to_alipay_dict()
+            if hasattr(self.label_names, 'to_alipay_dict'):
+                params['label_names'] = self.label_names.to_alipay_dict()
+            else:
+                params['label_names'] = self.label_names
+        if self.profiles:
+            if hasattr(self.profiles, 'to_alipay_dict'):
+                params['profiles'] = self.profiles.to_alipay_dict()
+            else:
+                params['profiles'] = self.profiles
         if self.role_list:
             if isinstance(self.role_list, list):
                 for i in range(0, len(self.role_list)):
@@ -140,6 +195,8 @@ class AlipayCommerceEcEmployeeInfoModifyModel(object):
         if not d:
             return None
         o = AlipayCommerceEcEmployeeInfoModifyModel()
+        if 'accounting_entity_ids' in d:
+            o.accounting_entity_ids = d['accounting_entity_ids']
         if 'department_ids' in d:
             o.department_ids = d['department_ids']
         if 'employee_email' in d:
@@ -154,6 +211,10 @@ class AlipayCommerceEcEmployeeInfoModifyModel(object):
             o.employee_no = d['employee_no']
         if 'enterprise_id' in d:
             o.enterprise_id = d['enterprise_id']
+        if 'label_names' in d:
+            o.label_names = d['label_names']
+        if 'profiles' in d:
+            o.profiles = d['profiles']
         if 'role_list' in d:
             o.role_list = d['role_list']
         return o
