@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.EcEmployeeTitleModifyTaxNoAndTitleId import EcEmployeeTitleModifyTaxNoAndTitleId
 
 
 class AlipayCommerceEcEmployeeTitleModifyModel(object):
@@ -13,9 +14,11 @@ class AlipayCommerceEcEmployeeTitleModifyModel(object):
         self._employee_id = None
         self._enterprise_id = None
         self._modify_by = None
+        self._multi_title_list = None
         self._new_title_id = None
         self._old_title_id = None
         self._open_id = None
+        self._tax_register_no = None
         self._title_tag = None
         self._user_id = None
 
@@ -55,6 +58,19 @@ class AlipayCommerceEcEmployeeTitleModifyModel(object):
     def modify_by(self, value):
         self._modify_by = value
     @property
+    def multi_title_list(self):
+        return self._multi_title_list
+
+    @multi_title_list.setter
+    def multi_title_list(self, value):
+        if isinstance(value, list):
+            self._multi_title_list = list()
+            for i in value:
+                if isinstance(i, EcEmployeeTitleModifyTaxNoAndTitleId):
+                    self._multi_title_list.append(i)
+                else:
+                    self._multi_title_list.append(EcEmployeeTitleModifyTaxNoAndTitleId.from_alipay_dict(i))
+    @property
     def new_title_id(self):
         return self._new_title_id
 
@@ -76,6 +92,13 @@ class AlipayCommerceEcEmployeeTitleModifyModel(object):
     def open_id(self, value):
         self._open_id = value
     @property
+    def tax_register_no(self):
+        return self._tax_register_no
+
+    @tax_register_no.setter
+    def tax_register_no(self, value):
+        self._tax_register_no = value
+    @property
     def title_tag(self):
         return self._title_tag
 
@@ -118,6 +141,16 @@ class AlipayCommerceEcEmployeeTitleModifyModel(object):
                 params['modify_by'] = self.modify_by.to_alipay_dict()
             else:
                 params['modify_by'] = self.modify_by
+        if self.multi_title_list:
+            if isinstance(self.multi_title_list, list):
+                for i in range(0, len(self.multi_title_list)):
+                    element = self.multi_title_list[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.multi_title_list[i] = element.to_alipay_dict()
+            if hasattr(self.multi_title_list, 'to_alipay_dict'):
+                params['multi_title_list'] = self.multi_title_list.to_alipay_dict()
+            else:
+                params['multi_title_list'] = self.multi_title_list
         if self.new_title_id:
             if hasattr(self.new_title_id, 'to_alipay_dict'):
                 params['new_title_id'] = self.new_title_id.to_alipay_dict()
@@ -133,6 +166,11 @@ class AlipayCommerceEcEmployeeTitleModifyModel(object):
                 params['open_id'] = self.open_id.to_alipay_dict()
             else:
                 params['open_id'] = self.open_id
+        if self.tax_register_no:
+            if hasattr(self.tax_register_no, 'to_alipay_dict'):
+                params['tax_register_no'] = self.tax_register_no.to_alipay_dict()
+            else:
+                params['tax_register_no'] = self.tax_register_no
         if self.title_tag:
             if hasattr(self.title_tag, 'to_alipay_dict'):
                 params['title_tag'] = self.title_tag.to_alipay_dict()
@@ -160,12 +198,16 @@ class AlipayCommerceEcEmployeeTitleModifyModel(object):
             o.enterprise_id = d['enterprise_id']
         if 'modify_by' in d:
             o.modify_by = d['modify_by']
+        if 'multi_title_list' in d:
+            o.multi_title_list = d['multi_title_list']
         if 'new_title_id' in d:
             o.new_title_id = d['new_title_id']
         if 'old_title_id' in d:
             o.old_title_id = d['old_title_id']
         if 'open_id' in d:
             o.open_id = d['open_id']
+        if 'tax_register_no' in d:
+            o.tax_register_no = d['tax_register_no']
         if 'title_tag' in d:
             o.title_tag = d['title_tag']
         if 'user_id' in d:
