@@ -16,6 +16,7 @@ class AlipayCommerceOperationIsvOrderSyncModel(object):
 
     def __init__(self):
         self._buyer_id = None
+        self._buyer_open_id = None
         self._catering_order_info = None
         self._delivery_info = None
         self._discount_amount = None
@@ -53,6 +54,13 @@ class AlipayCommerceOperationIsvOrderSyncModel(object):
     def buyer_id(self, value):
         self._buyer_id = value
     @property
+    def buyer_open_id(self):
+        return self._buyer_open_id
+
+    @buyer_open_id.setter
+    def buyer_open_id(self, value):
+        self._buyer_open_id = value
+    @property
     def catering_order_info(self):
         return self._catering_order_info
 
@@ -281,6 +289,11 @@ class AlipayCommerceOperationIsvOrderSyncModel(object):
                 params['buyer_id'] = self.buyer_id.to_alipay_dict()
             else:
                 params['buyer_id'] = self.buyer_id
+        if self.buyer_open_id:
+            if hasattr(self.buyer_open_id, 'to_alipay_dict'):
+                params['buyer_open_id'] = self.buyer_open_id.to_alipay_dict()
+            else:
+                params['buyer_open_id'] = self.buyer_open_id
         if self.catering_order_info:
             if hasattr(self.catering_order_info, 'to_alipay_dict'):
                 params['catering_order_info'] = self.catering_order_info.to_alipay_dict()
@@ -435,6 +448,8 @@ class AlipayCommerceOperationIsvOrderSyncModel(object):
         o = AlipayCommerceOperationIsvOrderSyncModel()
         if 'buyer_id' in d:
             o.buyer_id = d['buyer_id']
+        if 'buyer_open_id' in d:
+            o.buyer_open_id = d['buyer_open_id']
         if 'catering_order_info' in d:
             o.catering_order_info = d['catering_order_info']
         if 'delivery_info' in d:
