@@ -9,6 +9,7 @@ class AlipayCommerceYuntaskPointaccountQueryModel(object):
 
     def __init__(self):
         self._hunter_id = None
+        self._hunter_open_id = None
         self._merchant_pid = None
 
     @property
@@ -19,6 +20,13 @@ class AlipayCommerceYuntaskPointaccountQueryModel(object):
     def hunter_id(self, value):
         self._hunter_id = value
     @property
+    def hunter_open_id(self):
+        return self._hunter_open_id
+
+    @hunter_open_id.setter
+    def hunter_open_id(self, value):
+        self._hunter_open_id = value
+    @property
     def merchant_pid(self):
         return self._merchant_pid
 
@@ -34,6 +42,11 @@ class AlipayCommerceYuntaskPointaccountQueryModel(object):
                 params['hunter_id'] = self.hunter_id.to_alipay_dict()
             else:
                 params['hunter_id'] = self.hunter_id
+        if self.hunter_open_id:
+            if hasattr(self.hunter_open_id, 'to_alipay_dict'):
+                params['hunter_open_id'] = self.hunter_open_id.to_alipay_dict()
+            else:
+                params['hunter_open_id'] = self.hunter_open_id
         if self.merchant_pid:
             if hasattr(self.merchant_pid, 'to_alipay_dict'):
                 params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
@@ -48,6 +61,8 @@ class AlipayCommerceYuntaskPointaccountQueryModel(object):
         o = AlipayCommerceYuntaskPointaccountQueryModel()
         if 'hunter_id' in d:
             o.hunter_id = d['hunter_id']
+        if 'hunter_open_id' in d:
+            o.hunter_open_id = d['hunter_open_id']
         if 'merchant_pid' in d:
             o.merchant_pid = d['merchant_pid']
         return o
