@@ -10,6 +10,7 @@ class AlipayDataBillBizfundagentQueryModel(object):
     def __init__(self):
         self._account_book_id = None
         self._agreement_no = None
+        self._agreement_type = None
         self._end_time = None
         self._page_no = None
         self._page_size = None
@@ -30,6 +31,13 @@ class AlipayDataBillBizfundagentQueryModel(object):
     def agreement_no(self, value):
         self._agreement_no = value
     @property
+    def agreement_type(self):
+        return self._agreement_type
+
+    @agreement_type.setter
+    def agreement_type(self, value):
+        self._agreement_type = value
+    @property
     def end_time(self):
         return self._end_time
 
@@ -71,6 +79,11 @@ class AlipayDataBillBizfundagentQueryModel(object):
                 params['agreement_no'] = self.agreement_no.to_alipay_dict()
             else:
                 params['agreement_no'] = self.agreement_no
+        if self.agreement_type:
+            if hasattr(self.agreement_type, 'to_alipay_dict'):
+                params['agreement_type'] = self.agreement_type.to_alipay_dict()
+            else:
+                params['agreement_type'] = self.agreement_type
         if self.end_time:
             if hasattr(self.end_time, 'to_alipay_dict'):
                 params['end_time'] = self.end_time.to_alipay_dict()
@@ -102,6 +115,8 @@ class AlipayDataBillBizfundagentQueryModel(object):
             o.account_book_id = d['account_book_id']
         if 'agreement_no' in d:
             o.agreement_no = d['agreement_no']
+        if 'agreement_type' in d:
+            o.agreement_type = d['agreement_type']
         if 'end_time' in d:
             o.end_time = d['end_time']
         if 'page_no' in d:
