@@ -10,9 +10,12 @@ class AlipayDigitalopUcdpApebehaviorSyncModel(object):
     def __init__(self):
         self._action_type = None
         self._channel = None
+        self._custom_id = None
+        self._goods_id = None
         self._item_id_list = None
         self._item_num = None
         self._log_time = None
+        self._material_id = None
         self._open_id = None
         self._order_id = None
         self._page_stay = None
@@ -42,6 +45,20 @@ class AlipayDigitalopUcdpApebehaviorSyncModel(object):
     def channel(self, value):
         self._channel = value
     @property
+    def custom_id(self):
+        return self._custom_id
+
+    @custom_id.setter
+    def custom_id(self, value):
+        self._custom_id = value
+    @property
+    def goods_id(self):
+        return self._goods_id
+
+    @goods_id.setter
+    def goods_id(self, value):
+        self._goods_id = value
+    @property
     def item_id_list(self):
         return self._item_id_list
 
@@ -63,6 +80,13 @@ class AlipayDigitalopUcdpApebehaviorSyncModel(object):
     def log_time(self, value):
         self._log_time = value
     @property
+    def material_id(self):
+        return self._material_id
+
+    @material_id.setter
+    def material_id(self, value):
+        self._material_id = value
+    @property
     def open_id(self):
         return self._open_id
 
@@ -167,6 +191,16 @@ class AlipayDigitalopUcdpApebehaviorSyncModel(object):
                 params['channel'] = self.channel.to_alipay_dict()
             else:
                 params['channel'] = self.channel
+        if self.custom_id:
+            if hasattr(self.custom_id, 'to_alipay_dict'):
+                params['custom_id'] = self.custom_id.to_alipay_dict()
+            else:
+                params['custom_id'] = self.custom_id
+        if self.goods_id:
+            if hasattr(self.goods_id, 'to_alipay_dict'):
+                params['goods_id'] = self.goods_id.to_alipay_dict()
+            else:
+                params['goods_id'] = self.goods_id
         if self.item_id_list:
             if hasattr(self.item_id_list, 'to_alipay_dict'):
                 params['item_id_list'] = self.item_id_list.to_alipay_dict()
@@ -182,6 +216,11 @@ class AlipayDigitalopUcdpApebehaviorSyncModel(object):
                 params['log_time'] = self.log_time.to_alipay_dict()
             else:
                 params['log_time'] = self.log_time
+        if self.material_id:
+            if hasattr(self.material_id, 'to_alipay_dict'):
+                params['material_id'] = self.material_id.to_alipay_dict()
+            else:
+                params['material_id'] = self.material_id
         if self.open_id:
             if hasattr(self.open_id, 'to_alipay_dict'):
                 params['open_id'] = self.open_id.to_alipay_dict()
@@ -258,12 +297,18 @@ class AlipayDigitalopUcdpApebehaviorSyncModel(object):
             o.action_type = d['action_type']
         if 'channel' in d:
             o.channel = d['channel']
+        if 'custom_id' in d:
+            o.custom_id = d['custom_id']
+        if 'goods_id' in d:
+            o.goods_id = d['goods_id']
         if 'item_id_list' in d:
             o.item_id_list = d['item_id_list']
         if 'item_num' in d:
             o.item_num = d['item_num']
         if 'log_time' in d:
             o.log_time = d['log_time']
+        if 'material_id' in d:
+            o.material_id = d['material_id']
         if 'open_id' in d:
             o.open_id = d['open_id']
         if 'order_id' in d:
