@@ -9,6 +9,7 @@ class AlipayEbppIndustryNucleicremindSubscribeQueryModel(object):
 
     def __init__(self):
         self._city_code = None
+        self._open_id = None
         self._user_id = None
 
     @property
@@ -19,6 +20,13 @@ class AlipayEbppIndustryNucleicremindSubscribeQueryModel(object):
     def city_code(self, value):
         self._city_code = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def user_id(self):
         return self._user_id
 
@@ -34,6 +42,11 @@ class AlipayEbppIndustryNucleicremindSubscribeQueryModel(object):
                 params['city_code'] = self.city_code.to_alipay_dict()
             else:
                 params['city_code'] = self.city_code
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.user_id:
             if hasattr(self.user_id, 'to_alipay_dict'):
                 params['user_id'] = self.user_id.to_alipay_dict()
@@ -48,6 +61,8 @@ class AlipayEbppIndustryNucleicremindSubscribeQueryModel(object):
         o = AlipayEbppIndustryNucleicremindSubscribeQueryModel()
         if 'city_code' in d:
             o.city_code = d['city_code']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'user_id' in d:
             o.user_id = d['user_id']
         return o
