@@ -11,6 +11,7 @@ class AlipayEbppInvoiceEnterpriseexctrlEmployertitleQueryModel(object):
         self._account_id = None
         self._agreement_no = None
         self._enterprise_id = None
+        self._tax_register_no = None
         self._title_id = None
 
     @property
@@ -35,6 +36,13 @@ class AlipayEbppInvoiceEnterpriseexctrlEmployertitleQueryModel(object):
     def enterprise_id(self, value):
         self._enterprise_id = value
     @property
+    def tax_register_no(self):
+        return self._tax_register_no
+
+    @tax_register_no.setter
+    def tax_register_no(self, value):
+        self._tax_register_no = value
+    @property
     def title_id(self):
         return self._title_id
 
@@ -60,6 +68,11 @@ class AlipayEbppInvoiceEnterpriseexctrlEmployertitleQueryModel(object):
                 params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
             else:
                 params['enterprise_id'] = self.enterprise_id
+        if self.tax_register_no:
+            if hasattr(self.tax_register_no, 'to_alipay_dict'):
+                params['tax_register_no'] = self.tax_register_no.to_alipay_dict()
+            else:
+                params['tax_register_no'] = self.tax_register_no
         if self.title_id:
             if hasattr(self.title_id, 'to_alipay_dict'):
                 params['title_id'] = self.title_id.to_alipay_dict()
@@ -78,6 +91,8 @@ class AlipayEbppInvoiceEnterpriseexctrlEmployertitleQueryModel(object):
             o.agreement_no = d['agreement_no']
         if 'enterprise_id' in d:
             o.enterprise_id = d['enterprise_id']
+        if 'tax_register_no' in d:
+            o.tax_register_no = d['tax_register_no']
         if 'title_id' in d:
             o.title_id = d['title_id']
         return o
