@@ -10,6 +10,7 @@ class AlipayEcoMycarParkingAgreementQueryModel(object):
     def __init__(self):
         self._alipay_user_id = None
         self._car_number = None
+        self._open_id = None
         self._parking_id = None
         self._plate_color = None
         self._ver = None
@@ -29,6 +30,13 @@ class AlipayEcoMycarParkingAgreementQueryModel(object):
     def car_number(self, value):
         self._car_number = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def parking_id(self):
         return self._parking_id
 
@@ -63,6 +71,11 @@ class AlipayEcoMycarParkingAgreementQueryModel(object):
                 params['car_number'] = self.car_number.to_alipay_dict()
             else:
                 params['car_number'] = self.car_number
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.parking_id:
             if hasattr(self.parking_id, 'to_alipay_dict'):
                 params['parking_id'] = self.parking_id.to_alipay_dict()
@@ -89,6 +102,8 @@ class AlipayEcoMycarParkingAgreementQueryModel(object):
             o.alipay_user_id = d['alipay_user_id']
         if 'car_number' in d:
             o.car_number = d['car_number']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'parking_id' in d:
             o.parking_id = d['parking_id']
         if 'plate_color' in d:
