@@ -9,6 +9,7 @@ class AlipayFincoreComplianceTemplateComponentBatchqueryModel(object):
 
     def __init__(self):
         self._template_codes = None
+        self._template_lib_code = None
 
     @property
     def template_codes(self):
@@ -20,6 +21,13 @@ class AlipayFincoreComplianceTemplateComponentBatchqueryModel(object):
             self._template_codes = list()
             for i in value:
                 self._template_codes.append(i)
+    @property
+    def template_lib_code(self):
+        return self._template_lib_code
+
+    @template_lib_code.setter
+    def template_lib_code(self, value):
+        self._template_lib_code = value
 
 
     def to_alipay_dict(self):
@@ -34,6 +42,11 @@ class AlipayFincoreComplianceTemplateComponentBatchqueryModel(object):
                 params['template_codes'] = self.template_codes.to_alipay_dict()
             else:
                 params['template_codes'] = self.template_codes
+        if self.template_lib_code:
+            if hasattr(self.template_lib_code, 'to_alipay_dict'):
+                params['template_lib_code'] = self.template_lib_code.to_alipay_dict()
+            else:
+                params['template_lib_code'] = self.template_lib_code
         return params
 
     @staticmethod
@@ -43,6 +56,8 @@ class AlipayFincoreComplianceTemplateComponentBatchqueryModel(object):
         o = AlipayFincoreComplianceTemplateComponentBatchqueryModel()
         if 'template_codes' in d:
             o.template_codes = d['template_codes']
+        if 'template_lib_code' in d:
+            o.template_lib_code = d['template_lib_code']
         return o
 
 
