@@ -16,6 +16,7 @@ class AlipayFundJointaccountFundallocListQueryModel(object):
         self._identity = None
         self._identity_type = None
         self._last_id = None
+        self._open_id = None
         self._page_size = None
         self._product_code = None
         self._status_list = None
@@ -77,6 +78,13 @@ class AlipayFundJointaccountFundallocListQueryModel(object):
     def last_id(self, value):
         self._last_id = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def page_size(self):
         return self._page_size
 
@@ -144,6 +152,11 @@ class AlipayFundJointaccountFundallocListQueryModel(object):
                 params['last_id'] = self.last_id.to_alipay_dict()
             else:
                 params['last_id'] = self.last_id
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.page_size:
             if hasattr(self.page_size, 'to_alipay_dict'):
                 params['page_size'] = self.page_size.to_alipay_dict()
@@ -187,6 +200,8 @@ class AlipayFundJointaccountFundallocListQueryModel(object):
             o.identity_type = d['identity_type']
         if 'last_id' in d:
             o.last_id = d['last_id']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'page_size' in d:
             o.page_size = d['page_size']
         if 'product_code' in d:
