@@ -10,15 +10,24 @@ from alipay.aop.api.domain.WalletUseRule import WalletUseRule
 class AlipayFundWalletTemplateCreateModel(object):
 
     def __init__(self):
+        self._biz_identity = None
         self._biz_scene = None
         self._consume_extend = None
         self._has_large_details_scene = None
         self._out_biz_no = None
         self._product_code = None
+        self._support_wallet_use_rule_define = None
         self._wallet_template_name = None
         self._wallet_use_rule = None
 
     @property
+    def biz_identity(self):
+        return self._biz_identity
+
+    @biz_identity.setter
+    def biz_identity(self, value):
+        self._biz_identity = value
+    @property
     def biz_scene(self):
         return self._biz_scene
 
@@ -57,6 +66,13 @@ class AlipayFundWalletTemplateCreateModel(object):
     def product_code(self, value):
         self._product_code = value
     @property
+    def support_wallet_use_rule_define(self):
+        return self._support_wallet_use_rule_define
+
+    @support_wallet_use_rule_define.setter
+    def support_wallet_use_rule_define(self, value):
+        self._support_wallet_use_rule_define = value
+    @property
     def wallet_template_name(self):
         return self._wallet_template_name
 
@@ -77,6 +93,11 @@ class AlipayFundWalletTemplateCreateModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.biz_identity:
+            if hasattr(self.biz_identity, 'to_alipay_dict'):
+                params['biz_identity'] = self.biz_identity.to_alipay_dict()
+            else:
+                params['biz_identity'] = self.biz_identity
         if self.biz_scene:
             if hasattr(self.biz_scene, 'to_alipay_dict'):
                 params['biz_scene'] = self.biz_scene.to_alipay_dict()
@@ -102,6 +123,11 @@ class AlipayFundWalletTemplateCreateModel(object):
                 params['product_code'] = self.product_code.to_alipay_dict()
             else:
                 params['product_code'] = self.product_code
+        if self.support_wallet_use_rule_define:
+            if hasattr(self.support_wallet_use_rule_define, 'to_alipay_dict'):
+                params['support_wallet_use_rule_define'] = self.support_wallet_use_rule_define.to_alipay_dict()
+            else:
+                params['support_wallet_use_rule_define'] = self.support_wallet_use_rule_define
         if self.wallet_template_name:
             if hasattr(self.wallet_template_name, 'to_alipay_dict'):
                 params['wallet_template_name'] = self.wallet_template_name.to_alipay_dict()
@@ -119,6 +145,8 @@ class AlipayFundWalletTemplateCreateModel(object):
         if not d:
             return None
         o = AlipayFundWalletTemplateCreateModel()
+        if 'biz_identity' in d:
+            o.biz_identity = d['biz_identity']
         if 'biz_scene' in d:
             o.biz_scene = d['biz_scene']
         if 'consume_extend' in d:
@@ -129,6 +157,8 @@ class AlipayFundWalletTemplateCreateModel(object):
             o.out_biz_no = d['out_biz_no']
         if 'product_code' in d:
             o.product_code = d['product_code']
+        if 'support_wallet_use_rule_define' in d:
+            o.support_wallet_use_rule_define = d['support_wallet_use_rule_define']
         if 'wallet_template_name' in d:
             o.wallet_template_name = d['wallet_template_name']
         if 'wallet_use_rule' in d:
