@@ -9,6 +9,7 @@ class AlipayMarketingActivityPayeeinfoCreateModel(object):
 
     def __init__(self):
         self._payee_pid = None
+        self._payee_settle_mode = None
 
     @property
     def payee_pid(self):
@@ -17,6 +18,13 @@ class AlipayMarketingActivityPayeeinfoCreateModel(object):
     @payee_pid.setter
     def payee_pid(self, value):
         self._payee_pid = value
+    @property
+    def payee_settle_mode(self):
+        return self._payee_settle_mode
+
+    @payee_settle_mode.setter
+    def payee_settle_mode(self, value):
+        self._payee_settle_mode = value
 
 
     def to_alipay_dict(self):
@@ -26,6 +34,11 @@ class AlipayMarketingActivityPayeeinfoCreateModel(object):
                 params['payee_pid'] = self.payee_pid.to_alipay_dict()
             else:
                 params['payee_pid'] = self.payee_pid
+        if self.payee_settle_mode:
+            if hasattr(self.payee_settle_mode, 'to_alipay_dict'):
+                params['payee_settle_mode'] = self.payee_settle_mode.to_alipay_dict()
+            else:
+                params['payee_settle_mode'] = self.payee_settle_mode
         return params
 
     @staticmethod
@@ -35,6 +48,8 @@ class AlipayMarketingActivityPayeeinfoCreateModel(object):
         o = AlipayMarketingActivityPayeeinfoCreateModel()
         if 'payee_pid' in d:
             o.payee_pid = d['payee_pid']
+        if 'payee_settle_mode' in d:
+            o.payee_settle_mode = d['payee_settle_mode']
         return o
 
 
