@@ -9,6 +9,7 @@ class AlipayMerchantPayforprivilegeUserrelationQueryModel(object):
 
     def __init__(self):
         self._member_id = None
+        self._open_id = None
         self._user_id = None
 
     @property
@@ -19,6 +20,13 @@ class AlipayMerchantPayforprivilegeUserrelationQueryModel(object):
     def member_id(self, value):
         self._member_id = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def user_id(self):
         return self._user_id
 
@@ -34,6 +42,11 @@ class AlipayMerchantPayforprivilegeUserrelationQueryModel(object):
                 params['member_id'] = self.member_id.to_alipay_dict()
             else:
                 params['member_id'] = self.member_id
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.user_id:
             if hasattr(self.user_id, 'to_alipay_dict'):
                 params['user_id'] = self.user_id.to_alipay_dict()
@@ -48,6 +61,8 @@ class AlipayMerchantPayforprivilegeUserrelationQueryModel(object):
         o = AlipayMerchantPayforprivilegeUserrelationQueryModel()
         if 'member_id' in d:
             o.member_id = d['member_id']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'user_id' in d:
             o.user_id = d['user_id']
         return o
