@@ -8,10 +8,18 @@ from alipay.aop.api.constant.ParamConstants import *
 class AlipayOpenAuthUserauthTokenCreateModel(object):
 
     def __init__(self):
+        self._open_id = None
         self._scopes = None
         self._user_id = None
 
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def scopes(self):
         return self._scopes
 
@@ -29,6 +37,11 @@ class AlipayOpenAuthUserauthTokenCreateModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.scopes:
             if hasattr(self.scopes, 'to_alipay_dict'):
                 params['scopes'] = self.scopes.to_alipay_dict()
@@ -46,6 +59,8 @@ class AlipayOpenAuthUserauthTokenCreateModel(object):
         if not d:
             return None
         o = AlipayOpenAuthUserauthTokenCreateModel()
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'scopes' in d:
             o.scopes = d['scopes']
         if 'user_id' in d:
