@@ -9,6 +9,7 @@ class AlipayOpenOperationOpenbizmockTestauthtokenQueryModel(object):
 
     def __init__(self):
         self._a = None
+        self._a_open_id = None
 
     @property
     def a(self):
@@ -17,6 +18,13 @@ class AlipayOpenOperationOpenbizmockTestauthtokenQueryModel(object):
     @a.setter
     def a(self, value):
         self._a = value
+    @property
+    def a_open_id(self):
+        return self._a_open_id
+
+    @a_open_id.setter
+    def a_open_id(self, value):
+        self._a_open_id = value
 
 
     def to_alipay_dict(self):
@@ -26,6 +34,11 @@ class AlipayOpenOperationOpenbizmockTestauthtokenQueryModel(object):
                 params['a'] = self.a.to_alipay_dict()
             else:
                 params['a'] = self.a
+        if self.a_open_id:
+            if hasattr(self.a_open_id, 'to_alipay_dict'):
+                params['a_open_id'] = self.a_open_id.to_alipay_dict()
+            else:
+                params['a_open_id'] = self.a_open_id
         return params
 
     @staticmethod
@@ -35,6 +48,8 @@ class AlipayOpenOperationOpenbizmockTestauthtokenQueryModel(object):
         o = AlipayOpenOperationOpenbizmockTestauthtokenQueryModel()
         if 'a' in d:
             o.a = d['a']
+        if 'a_open_id' in d:
+            o.a_open_id = d['a_open_id']
         return o
 
 
