@@ -9,6 +9,7 @@ class AlipayOpenSearchAppkeywordDeleteModel(object):
 
     def __init__(self):
         self._config_id = None
+        self._key_words = None
         self._target_appid = None
 
     @property
@@ -19,6 +20,16 @@ class AlipayOpenSearchAppkeywordDeleteModel(object):
     def config_id(self, value):
         self._config_id = value
     @property
+    def key_words(self):
+        return self._key_words
+
+    @key_words.setter
+    def key_words(self, value):
+        if isinstance(value, list):
+            self._key_words = list()
+            for i in value:
+                self._key_words.append(i)
+    @property
     def target_appid(self):
         return self._target_appid
 
@@ -34,6 +45,16 @@ class AlipayOpenSearchAppkeywordDeleteModel(object):
                 params['config_id'] = self.config_id.to_alipay_dict()
             else:
                 params['config_id'] = self.config_id
+        if self.key_words:
+            if isinstance(self.key_words, list):
+                for i in range(0, len(self.key_words)):
+                    element = self.key_words[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.key_words[i] = element.to_alipay_dict()
+            if hasattr(self.key_words, 'to_alipay_dict'):
+                params['key_words'] = self.key_words.to_alipay_dict()
+            else:
+                params['key_words'] = self.key_words
         if self.target_appid:
             if hasattr(self.target_appid, 'to_alipay_dict'):
                 params['target_appid'] = self.target_appid.to_alipay_dict()
@@ -48,6 +69,8 @@ class AlipayOpenSearchAppkeywordDeleteModel(object):
         o = AlipayOpenSearchAppkeywordDeleteModel()
         if 'config_id' in d:
             o.config_id = d['config_id']
+        if 'key_words' in d:
+            o.key_words = d['key_words']
         if 'target_appid' in d:
             o.target_appid = d['target_appid']
         return o
