@@ -9,6 +9,7 @@ class AlipayTradeCreditOrderQueryModel(object):
 
     def __init__(self):
         self._credit_biz_order_id = None
+        self._out_trade_no = None
 
     @property
     def credit_biz_order_id(self):
@@ -17,6 +18,13 @@ class AlipayTradeCreditOrderQueryModel(object):
     @credit_biz_order_id.setter
     def credit_biz_order_id(self, value):
         self._credit_biz_order_id = value
+    @property
+    def out_trade_no(self):
+        return self._out_trade_no
+
+    @out_trade_no.setter
+    def out_trade_no(self, value):
+        self._out_trade_no = value
 
 
     def to_alipay_dict(self):
@@ -26,6 +34,11 @@ class AlipayTradeCreditOrderQueryModel(object):
                 params['credit_biz_order_id'] = self.credit_biz_order_id.to_alipay_dict()
             else:
                 params['credit_biz_order_id'] = self.credit_biz_order_id
+        if self.out_trade_no:
+            if hasattr(self.out_trade_no, 'to_alipay_dict'):
+                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
+            else:
+                params['out_trade_no'] = self.out_trade_no
         return params
 
     @staticmethod
@@ -35,6 +48,8 @@ class AlipayTradeCreditOrderQueryModel(object):
         o = AlipayTradeCreditOrderQueryModel()
         if 'credit_biz_order_id' in d:
             o.credit_biz_order_id = d['credit_biz_order_id']
+        if 'out_trade_no' in d:
+            o.out_trade_no = d['out_trade_no']
         return o
 
 
