@@ -4,6 +4,7 @@ import json
 
 from alipay.aop.api.constant.ParamConstants import *
 from alipay.aop.api.domain.AgreementParams import AgreementParams
+from alipay.aop.api.domain.BkAgentReqInfo import BkAgentReqInfo
 from alipay.aop.api.domain.BusinessParams import BusinessParams
 from alipay.aop.api.domain.ExtUserInfo import ExtUserInfo
 from alipay.aop.api.domain.ExtendParams import ExtendParams
@@ -24,9 +25,11 @@ class AlipayTradePayModel(object):
         self._auth_code = None
         self._auth_confirm_mode = None
         self._auth_no = None
+        self._bkagent_req_info = None
         self._body = None
         self._business_params = None
         self._buyer_id = None
+        self._buyer_open_id = None
         self._disable_pay_channels = None
         self._discountable_amount = None
         self._ext_user_info = None
@@ -104,6 +107,16 @@ class AlipayTradePayModel(object):
     def auth_no(self, value):
         self._auth_no = value
     @property
+    def bkagent_req_info(self):
+        return self._bkagent_req_info
+
+    @bkagent_req_info.setter
+    def bkagent_req_info(self, value):
+        if isinstance(value, BkAgentReqInfo):
+            self._bkagent_req_info = value
+        else:
+            self._bkagent_req_info = BkAgentReqInfo.from_alipay_dict(value)
+    @property
     def body(self):
         return self._body
 
@@ -128,6 +141,13 @@ class AlipayTradePayModel(object):
     def buyer_id(self, value):
         self._buyer_id = value
     @property
+    def buyer_open_id(self):
+        return self._buyer_open_id
+
+    @buyer_open_id.setter
+    def buyer_open_id(self, value):
+        self._buyer_open_id = value
+    @property
     def disable_pay_channels(self):
         return self._disable_pay_channels
 
@@ -401,6 +421,11 @@ class AlipayTradePayModel(object):
                 params['auth_no'] = self.auth_no.to_alipay_dict()
             else:
                 params['auth_no'] = self.auth_no
+        if self.bkagent_req_info:
+            if hasattr(self.bkagent_req_info, 'to_alipay_dict'):
+                params['bkagent_req_info'] = self.bkagent_req_info.to_alipay_dict()
+            else:
+                params['bkagent_req_info'] = self.bkagent_req_info
         if self.body:
             if hasattr(self.body, 'to_alipay_dict'):
                 params['body'] = self.body.to_alipay_dict()
@@ -416,6 +441,11 @@ class AlipayTradePayModel(object):
                 params['buyer_id'] = self.buyer_id.to_alipay_dict()
             else:
                 params['buyer_id'] = self.buyer_id
+        if self.buyer_open_id:
+            if hasattr(self.buyer_open_id, 'to_alipay_dict'):
+                params['buyer_open_id'] = self.buyer_open_id.to_alipay_dict()
+            else:
+                params['buyer_open_id'] = self.buyer_open_id
         if self.disable_pay_channels:
             if hasattr(self.disable_pay_channels, 'to_alipay_dict'):
                 params['disable_pay_channels'] = self.disable_pay_channels.to_alipay_dict()
@@ -595,12 +625,16 @@ class AlipayTradePayModel(object):
             o.auth_confirm_mode = d['auth_confirm_mode']
         if 'auth_no' in d:
             o.auth_no = d['auth_no']
+        if 'bkagent_req_info' in d:
+            o.bkagent_req_info = d['bkagent_req_info']
         if 'body' in d:
             o.body = d['body']
         if 'business_params' in d:
             o.business_params = d['business_params']
         if 'buyer_id' in d:
             o.buyer_id = d['buyer_id']
+        if 'buyer_open_id' in d:
+            o.buyer_open_id = d['buyer_open_id']
         if 'disable_pay_channels' in d:
             o.disable_pay_channels = d['disable_pay_channels']
         if 'discountable_amount' in d:
