@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.DeductOrderDetail import DeductOrderDetail
 
 
 class AlipayUserMpointAuthbasePayModel(object):
@@ -10,6 +11,7 @@ class AlipayUserMpointAuthbasePayModel(object):
     def __init__(self):
         self._biz_sub_type = None
         self._biz_type = None
+        self._deduct_order_detail = None
         self._open_id = None
         self._out_biz_no = None
         self._point = None
@@ -30,6 +32,16 @@ class AlipayUserMpointAuthbasePayModel(object):
     def biz_type(self, value):
         self._biz_type = value
     @property
+    def deduct_order_detail(self):
+        return self._deduct_order_detail
+
+    @deduct_order_detail.setter
+    def deduct_order_detail(self, value):
+        if isinstance(value, DeductOrderDetail):
+            self._deduct_order_detail = value
+        else:
+            self._deduct_order_detail = DeductOrderDetail.from_alipay_dict(value)
+    @property
     def open_id(self):
         return self._open_id
 
@@ -71,6 +83,11 @@ class AlipayUserMpointAuthbasePayModel(object):
                 params['biz_type'] = self.biz_type.to_alipay_dict()
             else:
                 params['biz_type'] = self.biz_type
+        if self.deduct_order_detail:
+            if hasattr(self.deduct_order_detail, 'to_alipay_dict'):
+                params['deduct_order_detail'] = self.deduct_order_detail.to_alipay_dict()
+            else:
+                params['deduct_order_detail'] = self.deduct_order_detail
         if self.open_id:
             if hasattr(self.open_id, 'to_alipay_dict'):
                 params['open_id'] = self.open_id.to_alipay_dict()
@@ -102,6 +119,8 @@ class AlipayUserMpointAuthbasePayModel(object):
             o.biz_sub_type = d['biz_sub_type']
         if 'biz_type' in d:
             o.biz_type = d['biz_type']
+        if 'deduct_order_detail' in d:
+            o.deduct_order_detail = d['deduct_order_detail']
         if 'open_id' in d:
             o.open_id = d['open_id']
         if 'out_biz_no' in d:
