@@ -49,7 +49,10 @@ class AssetProduceItem(object):
         self._receiver_address = None
         self._receiver_mobile = None
         self._receiver_name = None
+        self._related_children_out_biz_no_count = None
+        self._related_others_out_biz_no = None
         self._related_out_biz_no = None
+        self._related_parent_out_biz_no = None
         self._supplier_pid = None
         self._template_id = None
         self._template_name = None
@@ -346,6 +349,23 @@ class AssetProduceItem(object):
     def receiver_name(self, value):
         self._receiver_name = value
     @property
+    def related_children_out_biz_no_count(self):
+        return self._related_children_out_biz_no_count
+
+    @related_children_out_biz_no_count.setter
+    def related_children_out_biz_no_count(self, value):
+        self._related_children_out_biz_no_count = value
+    @property
+    def related_others_out_biz_no(self):
+        return self._related_others_out_biz_no
+
+    @related_others_out_biz_no.setter
+    def related_others_out_biz_no(self, value):
+        if isinstance(value, list):
+            self._related_others_out_biz_no = list()
+            for i in value:
+                self._related_others_out_biz_no.append(i)
+    @property
     def related_out_biz_no(self):
         return self._related_out_biz_no
 
@@ -353,6 +373,13 @@ class AssetProduceItem(object):
     def related_out_biz_no(self, value):
         self._related_out_biz_no = value
     @property
+    def related_parent_out_biz_no(self):
+        return self._related_parent_out_biz_no
+
+    @related_parent_out_biz_no.setter
+    def related_parent_out_biz_no(self, value):
+        self._related_parent_out_biz_no = value
+    @property
     def supplier_pid(self):
         return self._supplier_pid
 
@@ -601,11 +628,31 @@ class AssetProduceItem(object):
                 params['receiver_name'] = self.receiver_name.to_alipay_dict()
             else:
                 params['receiver_name'] = self.receiver_name
+        if self.related_children_out_biz_no_count:
+            if hasattr(self.related_children_out_biz_no_count, 'to_alipay_dict'):
+                params['related_children_out_biz_no_count'] = self.related_children_out_biz_no_count.to_alipay_dict()
+            else:
+                params['related_children_out_biz_no_count'] = self.related_children_out_biz_no_count
+        if self.related_others_out_biz_no:
+            if isinstance(self.related_others_out_biz_no, list):
+                for i in range(0, len(self.related_others_out_biz_no)):
+                    element = self.related_others_out_biz_no[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.related_others_out_biz_no[i] = element.to_alipay_dict()
+            if hasattr(self.related_others_out_biz_no, 'to_alipay_dict'):
+                params['related_others_out_biz_no'] = self.related_others_out_biz_no.to_alipay_dict()
+            else:
+                params['related_others_out_biz_no'] = self.related_others_out_biz_no
         if self.related_out_biz_no:
             if hasattr(self.related_out_biz_no, 'to_alipay_dict'):
                 params['related_out_biz_no'] = self.related_out_biz_no.to_alipay_dict()
             else:
                 params['related_out_biz_no'] = self.related_out_biz_no
+        if self.related_parent_out_biz_no:
+            if hasattr(self.related_parent_out_biz_no, 'to_alipay_dict'):
+                params['related_parent_out_biz_no'] = self.related_parent_out_biz_no.to_alipay_dict()
+            else:
+                params['related_parent_out_biz_no'] = self.related_parent_out_biz_no
         if self.supplier_pid:
             if hasattr(self.supplier_pid, 'to_alipay_dict'):
                 params['supplier_pid'] = self.supplier_pid.to_alipay_dict()
@@ -718,8 +765,14 @@ class AssetProduceItem(object):
             o.receiver_mobile = d['receiver_mobile']
         if 'receiver_name' in d:
             o.receiver_name = d['receiver_name']
+        if 'related_children_out_biz_no_count' in d:
+            o.related_children_out_biz_no_count = d['related_children_out_biz_no_count']
+        if 'related_others_out_biz_no' in d:
+            o.related_others_out_biz_no = d['related_others_out_biz_no']
         if 'related_out_biz_no' in d:
             o.related_out_biz_no = d['related_out_biz_no']
+        if 'related_parent_out_biz_no' in d:
+            o.related_parent_out_biz_no = d['related_parent_out_biz_no']
         if 'supplier_pid' in d:
             o.supplier_pid = d['supplier_pid']
         if 'template_id' in d:
