@@ -5,9 +5,11 @@ import json
 from alipay.aop.api.constant.ParamConstants import *
 from alipay.aop.api.domain.DeliveryAvailableScope import DeliveryAvailableScope
 from alipay.aop.api.domain.DeliveryCityCodeRule import DeliveryCityCodeRule
+from alipay.aop.api.domain.DeliveryCrowdRule import DeliveryCrowdRule
 from alipay.aop.api.domain.DeliveryMerchantInfo import DeliveryMerchantInfo
 from alipay.aop.api.domain.DeliveryMerchantRule import DeliveryMerchantRule
 from alipay.aop.api.domain.DeliverySearchBoxRule import DeliverySearchBoxRule
+from alipay.aop.api.domain.DeliveryTemplateRule import DeliveryTemplateRule
 
 
 class DeliveryTargetRule(object):
@@ -16,12 +18,14 @@ class DeliveryTargetRule(object):
         self._brand_id_list = None
         self._delivery_available_scope = None
         self._delivery_city_code_rule = None
+        self._delivery_crowd_rule = None
         self._delivery_merchant_infos = None
         self._delivery_merchant_mode = None
         self._delivery_merchant_rule = None
         self._delivery_promo_tags = None
         self._delivery_recall_mode = None
         self._delivery_search_box_rule = None
+        self._delivery_template_rule = None
         self._delivery_type = None
 
     @property
@@ -55,6 +59,16 @@ class DeliveryTargetRule(object):
         else:
             self._delivery_city_code_rule = DeliveryCityCodeRule.from_alipay_dict(value)
     @property
+    def delivery_crowd_rule(self):
+        return self._delivery_crowd_rule
+
+    @delivery_crowd_rule.setter
+    def delivery_crowd_rule(self, value):
+        if isinstance(value, DeliveryCrowdRule):
+            self._delivery_crowd_rule = value
+        else:
+            self._delivery_crowd_rule = DeliveryCrowdRule.from_alipay_dict(value)
+    @property
     def delivery_merchant_infos(self):
         return self._delivery_merchant_infos
 
@@ -109,6 +123,16 @@ class DeliveryTargetRule(object):
         else:
             self._delivery_search_box_rule = DeliverySearchBoxRule.from_alipay_dict(value)
     @property
+    def delivery_template_rule(self):
+        return self._delivery_template_rule
+
+    @delivery_template_rule.setter
+    def delivery_template_rule(self, value):
+        if isinstance(value, DeliveryTemplateRule):
+            self._delivery_template_rule = value
+        else:
+            self._delivery_template_rule = DeliveryTemplateRule.from_alipay_dict(value)
+    @property
     def delivery_type(self):
         return self._delivery_type
 
@@ -139,6 +163,11 @@ class DeliveryTargetRule(object):
                 params['delivery_city_code_rule'] = self.delivery_city_code_rule.to_alipay_dict()
             else:
                 params['delivery_city_code_rule'] = self.delivery_city_code_rule
+        if self.delivery_crowd_rule:
+            if hasattr(self.delivery_crowd_rule, 'to_alipay_dict'):
+                params['delivery_crowd_rule'] = self.delivery_crowd_rule.to_alipay_dict()
+            else:
+                params['delivery_crowd_rule'] = self.delivery_crowd_rule
         if self.delivery_merchant_infos:
             if isinstance(self.delivery_merchant_infos, list):
                 for i in range(0, len(self.delivery_merchant_infos)):
@@ -174,6 +203,11 @@ class DeliveryTargetRule(object):
                 params['delivery_search_box_rule'] = self.delivery_search_box_rule.to_alipay_dict()
             else:
                 params['delivery_search_box_rule'] = self.delivery_search_box_rule
+        if self.delivery_template_rule:
+            if hasattr(self.delivery_template_rule, 'to_alipay_dict'):
+                params['delivery_template_rule'] = self.delivery_template_rule.to_alipay_dict()
+            else:
+                params['delivery_template_rule'] = self.delivery_template_rule
         if self.delivery_type:
             if hasattr(self.delivery_type, 'to_alipay_dict'):
                 params['delivery_type'] = self.delivery_type.to_alipay_dict()
@@ -192,6 +226,8 @@ class DeliveryTargetRule(object):
             o.delivery_available_scope = d['delivery_available_scope']
         if 'delivery_city_code_rule' in d:
             o.delivery_city_code_rule = d['delivery_city_code_rule']
+        if 'delivery_crowd_rule' in d:
+            o.delivery_crowd_rule = d['delivery_crowd_rule']
         if 'delivery_merchant_infos' in d:
             o.delivery_merchant_infos = d['delivery_merchant_infos']
         if 'delivery_merchant_mode' in d:
@@ -204,6 +240,8 @@ class DeliveryTargetRule(object):
             o.delivery_recall_mode = d['delivery_recall_mode']
         if 'delivery_search_box_rule' in d:
             o.delivery_search_box_rule = d['delivery_search_box_rule']
+        if 'delivery_template_rule' in d:
+            o.delivery_template_rule = d['delivery_template_rule']
         if 'delivery_type' in d:
             o.delivery_type = d['delivery_type']
         return o
