@@ -11,6 +11,7 @@ class FxiaokeCreateLeadsParams(object):
     def __init__(self):
         self._actual_lead_party = None
         self._ali_cloud_bpid_list = None
+        self._alicloud_settlement_mode = None
         self._bid_type = None
         self._cbm_work_no_list = None
         self._cloud_platform_region = None
@@ -23,11 +24,28 @@ class FxiaokeCreateLeadsParams(object):
         self._deploy_type = None
         self._expect_bid_date = None
         self._expect_sign_date = None
+        self._final_customer_sign_other_party_subject_id = None
+        self._final_customer_sign_other_party_subject_name = None
+        self._final_customer_sign_subject_id = None
+        self._final_customer_sign_subject_name = None
+        self._general_agent_cooperation_type = None
         self._id = None
+        self._if_resource_pool = None
         self._is_bid = None
         self._is_issue_for_bid = None
         self._leads_code = None
+        self._leads_deploy_resource_pedestals = None
+        self._leads_fee_model = None
+        self._leads_normandy = None
+        self._leads_other_cloud_pedestal = None
+        self._leads_other_partners = None
+        self._leads_other_partners_name = None
+        self._leads_product_type = None
+        self._leads_sale_channel = None
+        self._leads_sale_territory = None
         self._leads_source_partner_id = None
+        self._ob_sign_other_party_subject_id = None
+        self._ob_sign_other_party_subject_name = None
         self._other_partner_pid_list = None
         self._other_party_sign_subject = None
         self._other_party_sign_subject_id = None
@@ -65,6 +83,13 @@ class FxiaokeCreateLeadsParams(object):
     def ali_cloud_bpid_list(self, value):
         self._ali_cloud_bpid_list = value
     @property
+    def alicloud_settlement_mode(self):
+        return self._alicloud_settlement_mode
+
+    @alicloud_settlement_mode.setter
+    def alicloud_settlement_mode(self, value):
+        self._alicloud_settlement_mode = value
+    @property
     def bid_type(self):
         return self._bid_type
 
@@ -152,6 +177,41 @@ class FxiaokeCreateLeadsParams(object):
     def expect_sign_date(self, value):
         self._expect_sign_date = value
     @property
+    def final_customer_sign_other_party_subject_id(self):
+        return self._final_customer_sign_other_party_subject_id
+
+    @final_customer_sign_other_party_subject_id.setter
+    def final_customer_sign_other_party_subject_id(self, value):
+        self._final_customer_sign_other_party_subject_id = value
+    @property
+    def final_customer_sign_other_party_subject_name(self):
+        return self._final_customer_sign_other_party_subject_name
+
+    @final_customer_sign_other_party_subject_name.setter
+    def final_customer_sign_other_party_subject_name(self, value):
+        self._final_customer_sign_other_party_subject_name = value
+    @property
+    def final_customer_sign_subject_id(self):
+        return self._final_customer_sign_subject_id
+
+    @final_customer_sign_subject_id.setter
+    def final_customer_sign_subject_id(self, value):
+        self._final_customer_sign_subject_id = value
+    @property
+    def final_customer_sign_subject_name(self):
+        return self._final_customer_sign_subject_name
+
+    @final_customer_sign_subject_name.setter
+    def final_customer_sign_subject_name(self, value):
+        self._final_customer_sign_subject_name = value
+    @property
+    def general_agent_cooperation_type(self):
+        return self._general_agent_cooperation_type
+
+    @general_agent_cooperation_type.setter
+    def general_agent_cooperation_type(self, value):
+        self._general_agent_cooperation_type = value
+    @property
     def id(self):
         return self._id
 
@@ -159,6 +219,13 @@ class FxiaokeCreateLeadsParams(object):
     def id(self, value):
         self._id = value
     @property
+    def if_resource_pool(self):
+        return self._if_resource_pool
+
+    @if_resource_pool.setter
+    def if_resource_pool(self, value):
+        self._if_resource_pool = value
+    @property
     def is_bid(self):
         return self._is_bid
 
@@ -180,6 +247,69 @@ class FxiaokeCreateLeadsParams(object):
     def leads_code(self, value):
         self._leads_code = value
     @property
+    def leads_deploy_resource_pedestals(self):
+        return self._leads_deploy_resource_pedestals
+
+    @leads_deploy_resource_pedestals.setter
+    def leads_deploy_resource_pedestals(self, value):
+        self._leads_deploy_resource_pedestals = value
+    @property
+    def leads_fee_model(self):
+        return self._leads_fee_model
+
+    @leads_fee_model.setter
+    def leads_fee_model(self, value):
+        self._leads_fee_model = value
+    @property
+    def leads_normandy(self):
+        return self._leads_normandy
+
+    @leads_normandy.setter
+    def leads_normandy(self, value):
+        self._leads_normandy = value
+    @property
+    def leads_other_cloud_pedestal(self):
+        return self._leads_other_cloud_pedestal
+
+    @leads_other_cloud_pedestal.setter
+    def leads_other_cloud_pedestal(self, value):
+        self._leads_other_cloud_pedestal = value
+    @property
+    def leads_other_partners(self):
+        return self._leads_other_partners
+
+    @leads_other_partners.setter
+    def leads_other_partners(self, value):
+        self._leads_other_partners = value
+    @property
+    def leads_other_partners_name(self):
+        return self._leads_other_partners_name
+
+    @leads_other_partners_name.setter
+    def leads_other_partners_name(self, value):
+        self._leads_other_partners_name = value
+    @property
+    def leads_product_type(self):
+        return self._leads_product_type
+
+    @leads_product_type.setter
+    def leads_product_type(self, value):
+        self._leads_product_type = value
+    @property
+    def leads_sale_channel(self):
+        return self._leads_sale_channel
+
+    @leads_sale_channel.setter
+    def leads_sale_channel(self, value):
+        self._leads_sale_channel = value
+    @property
+    def leads_sale_territory(self):
+        return self._leads_sale_territory
+
+    @leads_sale_territory.setter
+    def leads_sale_territory(self, value):
+        self._leads_sale_territory = value
+    @property
     def leads_source_partner_id(self):
         return self._leads_source_partner_id
 
@@ -187,6 +317,20 @@ class FxiaokeCreateLeadsParams(object):
     def leads_source_partner_id(self, value):
         self._leads_source_partner_id = value
     @property
+    def ob_sign_other_party_subject_id(self):
+        return self._ob_sign_other_party_subject_id
+
+    @ob_sign_other_party_subject_id.setter
+    def ob_sign_other_party_subject_id(self, value):
+        self._ob_sign_other_party_subject_id = value
+    @property
+    def ob_sign_other_party_subject_name(self):
+        return self._ob_sign_other_party_subject_name
+
+    @ob_sign_other_party_subject_name.setter
+    def ob_sign_other_party_subject_name(self, value):
+        self._ob_sign_other_party_subject_name = value
+    @property
     def other_partner_pid_list(self):
         return self._other_partner_pid_list
 
@@ -356,6 +500,11 @@ class FxiaokeCreateLeadsParams(object):
                 params['ali_cloud_bpid_list'] = self.ali_cloud_bpid_list.to_alipay_dict()
             else:
                 params['ali_cloud_bpid_list'] = self.ali_cloud_bpid_list
+        if self.alicloud_settlement_mode:
+            if hasattr(self.alicloud_settlement_mode, 'to_alipay_dict'):
+                params['alicloud_settlement_mode'] = self.alicloud_settlement_mode.to_alipay_dict()
+            else:
+                params['alicloud_settlement_mode'] = self.alicloud_settlement_mode
         if self.bid_type:
             if hasattr(self.bid_type, 'to_alipay_dict'):
                 params['bid_type'] = self.bid_type.to_alipay_dict()
@@ -421,11 +570,41 @@ class FxiaokeCreateLeadsParams(object):
                 params['expect_sign_date'] = self.expect_sign_date.to_alipay_dict()
             else:
                 params['expect_sign_date'] = self.expect_sign_date
+        if self.final_customer_sign_other_party_subject_id:
+            if hasattr(self.final_customer_sign_other_party_subject_id, 'to_alipay_dict'):
+                params['final_customer_sign_other_party_subject_id'] = self.final_customer_sign_other_party_subject_id.to_alipay_dict()
+            else:
+                params['final_customer_sign_other_party_subject_id'] = self.final_customer_sign_other_party_subject_id
+        if self.final_customer_sign_other_party_subject_name:
+            if hasattr(self.final_customer_sign_other_party_subject_name, 'to_alipay_dict'):
+                params['final_customer_sign_other_party_subject_name'] = self.final_customer_sign_other_party_subject_name.to_alipay_dict()
+            else:
+                params['final_customer_sign_other_party_subject_name'] = self.final_customer_sign_other_party_subject_name
+        if self.final_customer_sign_subject_id:
+            if hasattr(self.final_customer_sign_subject_id, 'to_alipay_dict'):
+                params['final_customer_sign_subject_id'] = self.final_customer_sign_subject_id.to_alipay_dict()
+            else:
+                params['final_customer_sign_subject_id'] = self.final_customer_sign_subject_id
+        if self.final_customer_sign_subject_name:
+            if hasattr(self.final_customer_sign_subject_name, 'to_alipay_dict'):
+                params['final_customer_sign_subject_name'] = self.final_customer_sign_subject_name.to_alipay_dict()
+            else:
+                params['final_customer_sign_subject_name'] = self.final_customer_sign_subject_name
+        if self.general_agent_cooperation_type:
+            if hasattr(self.general_agent_cooperation_type, 'to_alipay_dict'):
+                params['general_agent_cooperation_type'] = self.general_agent_cooperation_type.to_alipay_dict()
+            else:
+                params['general_agent_cooperation_type'] = self.general_agent_cooperation_type
         if self.id:
             if hasattr(self.id, 'to_alipay_dict'):
                 params['id'] = self.id.to_alipay_dict()
             else:
                 params['id'] = self.id
+        if self.if_resource_pool:
+            if hasattr(self.if_resource_pool, 'to_alipay_dict'):
+                params['if_resource_pool'] = self.if_resource_pool.to_alipay_dict()
+            else:
+                params['if_resource_pool'] = self.if_resource_pool
         if self.is_bid:
             if hasattr(self.is_bid, 'to_alipay_dict'):
                 params['is_bid'] = self.is_bid.to_alipay_dict()
@@ -441,11 +620,66 @@ class FxiaokeCreateLeadsParams(object):
                 params['leads_code'] = self.leads_code.to_alipay_dict()
             else:
                 params['leads_code'] = self.leads_code
+        if self.leads_deploy_resource_pedestals:
+            if hasattr(self.leads_deploy_resource_pedestals, 'to_alipay_dict'):
+                params['leads_deploy_resource_pedestals'] = self.leads_deploy_resource_pedestals.to_alipay_dict()
+            else:
+                params['leads_deploy_resource_pedestals'] = self.leads_deploy_resource_pedestals
+        if self.leads_fee_model:
+            if hasattr(self.leads_fee_model, 'to_alipay_dict'):
+                params['leads_fee_model'] = self.leads_fee_model.to_alipay_dict()
+            else:
+                params['leads_fee_model'] = self.leads_fee_model
+        if self.leads_normandy:
+            if hasattr(self.leads_normandy, 'to_alipay_dict'):
+                params['leads_normandy'] = self.leads_normandy.to_alipay_dict()
+            else:
+                params['leads_normandy'] = self.leads_normandy
+        if self.leads_other_cloud_pedestal:
+            if hasattr(self.leads_other_cloud_pedestal, 'to_alipay_dict'):
+                params['leads_other_cloud_pedestal'] = self.leads_other_cloud_pedestal.to_alipay_dict()
+            else:
+                params['leads_other_cloud_pedestal'] = self.leads_other_cloud_pedestal
+        if self.leads_other_partners:
+            if hasattr(self.leads_other_partners, 'to_alipay_dict'):
+                params['leads_other_partners'] = self.leads_other_partners.to_alipay_dict()
+            else:
+                params['leads_other_partners'] = self.leads_other_partners
+        if self.leads_other_partners_name:
+            if hasattr(self.leads_other_partners_name, 'to_alipay_dict'):
+                params['leads_other_partners_name'] = self.leads_other_partners_name.to_alipay_dict()
+            else:
+                params['leads_other_partners_name'] = self.leads_other_partners_name
+        if self.leads_product_type:
+            if hasattr(self.leads_product_type, 'to_alipay_dict'):
+                params['leads_product_type'] = self.leads_product_type.to_alipay_dict()
+            else:
+                params['leads_product_type'] = self.leads_product_type
+        if self.leads_sale_channel:
+            if hasattr(self.leads_sale_channel, 'to_alipay_dict'):
+                params['leads_sale_channel'] = self.leads_sale_channel.to_alipay_dict()
+            else:
+                params['leads_sale_channel'] = self.leads_sale_channel
+        if self.leads_sale_territory:
+            if hasattr(self.leads_sale_territory, 'to_alipay_dict'):
+                params['leads_sale_territory'] = self.leads_sale_territory.to_alipay_dict()
+            else:
+                params['leads_sale_territory'] = self.leads_sale_territory
         if self.leads_source_partner_id:
             if hasattr(self.leads_source_partner_id, 'to_alipay_dict'):
                 params['leads_source_partner_id'] = self.leads_source_partner_id.to_alipay_dict()
             else:
                 params['leads_source_partner_id'] = self.leads_source_partner_id
+        if self.ob_sign_other_party_subject_id:
+            if hasattr(self.ob_sign_other_party_subject_id, 'to_alipay_dict'):
+                params['ob_sign_other_party_subject_id'] = self.ob_sign_other_party_subject_id.to_alipay_dict()
+            else:
+                params['ob_sign_other_party_subject_id'] = self.ob_sign_other_party_subject_id
+        if self.ob_sign_other_party_subject_name:
+            if hasattr(self.ob_sign_other_party_subject_name, 'to_alipay_dict'):
+                params['ob_sign_other_party_subject_name'] = self.ob_sign_other_party_subject_name.to_alipay_dict()
+            else:
+                params['ob_sign_other_party_subject_name'] = self.ob_sign_other_party_subject_name
         if self.other_partner_pid_list:
             if isinstance(self.other_partner_pid_list, list):
                 for i in range(0, len(self.other_partner_pid_list)):
@@ -572,6 +806,8 @@ class FxiaokeCreateLeadsParams(object):
             o.actual_lead_party = d['actual_lead_party']
         if 'ali_cloud_bpid_list' in d:
             o.ali_cloud_bpid_list = d['ali_cloud_bpid_list']
+        if 'alicloud_settlement_mode' in d:
+            o.alicloud_settlement_mode = d['alicloud_settlement_mode']
         if 'bid_type' in d:
             o.bid_type = d['bid_type']
         if 'cbm_work_no_list' in d:
@@ -596,16 +832,50 @@ class FxiaokeCreateLeadsParams(object):
             o.expect_bid_date = d['expect_bid_date']
         if 'expect_sign_date' in d:
             o.expect_sign_date = d['expect_sign_date']
+        if 'final_customer_sign_other_party_subject_id' in d:
+            o.final_customer_sign_other_party_subject_id = d['final_customer_sign_other_party_subject_id']
+        if 'final_customer_sign_other_party_subject_name' in d:
+            o.final_customer_sign_other_party_subject_name = d['final_customer_sign_other_party_subject_name']
+        if 'final_customer_sign_subject_id' in d:
+            o.final_customer_sign_subject_id = d['final_customer_sign_subject_id']
+        if 'final_customer_sign_subject_name' in d:
+            o.final_customer_sign_subject_name = d['final_customer_sign_subject_name']
+        if 'general_agent_cooperation_type' in d:
+            o.general_agent_cooperation_type = d['general_agent_cooperation_type']
         if 'id' in d:
             o.id = d['id']
+        if 'if_resource_pool' in d:
+            o.if_resource_pool = d['if_resource_pool']
         if 'is_bid' in d:
             o.is_bid = d['is_bid']
         if 'is_issue_for_bid' in d:
             o.is_issue_for_bid = d['is_issue_for_bid']
         if 'leads_code' in d:
             o.leads_code = d['leads_code']
+        if 'leads_deploy_resource_pedestals' in d:
+            o.leads_deploy_resource_pedestals = d['leads_deploy_resource_pedestals']
+        if 'leads_fee_model' in d:
+            o.leads_fee_model = d['leads_fee_model']
+        if 'leads_normandy' in d:
+            o.leads_normandy = d['leads_normandy']
+        if 'leads_other_cloud_pedestal' in d:
+            o.leads_other_cloud_pedestal = d['leads_other_cloud_pedestal']
+        if 'leads_other_partners' in d:
+            o.leads_other_partners = d['leads_other_partners']
+        if 'leads_other_partners_name' in d:
+            o.leads_other_partners_name = d['leads_other_partners_name']
+        if 'leads_product_type' in d:
+            o.leads_product_type = d['leads_product_type']
+        if 'leads_sale_channel' in d:
+            o.leads_sale_channel = d['leads_sale_channel']
+        if 'leads_sale_territory' in d:
+            o.leads_sale_territory = d['leads_sale_territory']
         if 'leads_source_partner_id' in d:
             o.leads_source_partner_id = d['leads_source_partner_id']
+        if 'ob_sign_other_party_subject_id' in d:
+            o.ob_sign_other_party_subject_id = d['ob_sign_other_party_subject_id']
+        if 'ob_sign_other_party_subject_name' in d:
+            o.ob_sign_other_party_subject_name = d['ob_sign_other_party_subject_name']
         if 'other_partner_pid_list' in d:
             o.other_partner_pid_list = d['other_partner_pid_list']
         if 'other_party_sign_subject' in d:
