@@ -3,12 +3,14 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.AttrExtInfoDTO import AttrExtInfoDTO
 from alipay.aop.api.domain.RentInfoDTO import RentInfoDTO
 
 
 class GoodsInfoModifyDTO(object):
 
     def __init__(self):
+        self._attr_ext_info_list = None
         self._inspect_price = None
         self._out_item_id = None
         self._out_sku_id = None
@@ -16,6 +18,19 @@ class GoodsInfoModifyDTO(object):
         self._rent_info = None
 
     @property
+    def attr_ext_info_list(self):
+        return self._attr_ext_info_list
+
+    @attr_ext_info_list.setter
+    def attr_ext_info_list(self, value):
+        if isinstance(value, list):
+            self._attr_ext_info_list = list()
+            for i in value:
+                if isinstance(i, AttrExtInfoDTO):
+                    self._attr_ext_info_list.append(i)
+                else:
+                    self._attr_ext_info_list.append(AttrExtInfoDTO.from_alipay_dict(i))
+    @property
     def inspect_price(self):
         return self._inspect_price
 
@@ -57,6 +72,16 @@ class GoodsInfoModifyDTO(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.attr_ext_info_list:
+            if isinstance(self.attr_ext_info_list, list):
+                for i in range(0, len(self.attr_ext_info_list)):
+                    element = self.attr_ext_info_list[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.attr_ext_info_list[i] = element.to_alipay_dict()
+            if hasattr(self.attr_ext_info_list, 'to_alipay_dict'):
+                params['attr_ext_info_list'] = self.attr_ext_info_list.to_alipay_dict()
+            else:
+                params['attr_ext_info_list'] = self.attr_ext_info_list
         if self.inspect_price:
             if hasattr(self.inspect_price, 'to_alipay_dict'):
                 params['inspect_price'] = self.inspect_price.to_alipay_dict()
@@ -89,6 +114,8 @@ class GoodsInfoModifyDTO(object):
         if not d:
             return None
         o = GoodsInfoModifyDTO()
+        if 'attr_ext_info_list' in d:
+            o.attr_ext_info_list = d['attr_ext_info_list']
         if 'inspect_price' in d:
             o.inspect_price = d['inspect_price']
         if 'out_item_id' in d:
