@@ -9,6 +9,7 @@ class HbFqPayInfo(object):
 
     def __init__(self):
         self._fq_amount = None
+        self._fq_inst_id = None
         self._user_install_num = None
 
     @property
@@ -19,6 +20,13 @@ class HbFqPayInfo(object):
     def fq_amount(self, value):
         self._fq_amount = value
     @property
+    def fq_inst_id(self):
+        return self._fq_inst_id
+
+    @fq_inst_id.setter
+    def fq_inst_id(self, value):
+        self._fq_inst_id = value
+    @property
     def user_install_num(self):
         return self._user_install_num
 
@@ -34,6 +42,11 @@ class HbFqPayInfo(object):
                 params['fq_amount'] = self.fq_amount.to_alipay_dict()
             else:
                 params['fq_amount'] = self.fq_amount
+        if self.fq_inst_id:
+            if hasattr(self.fq_inst_id, 'to_alipay_dict'):
+                params['fq_inst_id'] = self.fq_inst_id.to_alipay_dict()
+            else:
+                params['fq_inst_id'] = self.fq_inst_id
         if self.user_install_num:
             if hasattr(self.user_install_num, 'to_alipay_dict'):
                 params['user_install_num'] = self.user_install_num.to_alipay_dict()
@@ -48,6 +61,8 @@ class HbFqPayInfo(object):
         o = HbFqPayInfo()
         if 'fq_amount' in d:
             o.fq_amount = d['fq_amount']
+        if 'fq_inst_id' in d:
+            o.fq_inst_id = d['fq_inst_id']
         if 'user_install_num' in d:
             o.user_install_num = d['user_install_num']
         return o
