@@ -9,6 +9,7 @@ class ItemSkuAttrVO(object):
 
     def __init__(self):
         self._attr_key = None
+        self._attr_type = None
         self._attr_value = None
 
     @property
@@ -19,6 +20,13 @@ class ItemSkuAttrVO(object):
     def attr_key(self, value):
         self._attr_key = value
     @property
+    def attr_type(self):
+        return self._attr_type
+
+    @attr_type.setter
+    def attr_type(self, value):
+        self._attr_type = value
+    @property
     def attr_value(self):
         return self._attr_value
 
@@ -34,6 +42,11 @@ class ItemSkuAttrVO(object):
                 params['attr_key'] = self.attr_key.to_alipay_dict()
             else:
                 params['attr_key'] = self.attr_key
+        if self.attr_type:
+            if hasattr(self.attr_type, 'to_alipay_dict'):
+                params['attr_type'] = self.attr_type.to_alipay_dict()
+            else:
+                params['attr_type'] = self.attr_type
         if self.attr_value:
             if hasattr(self.attr_value, 'to_alipay_dict'):
                 params['attr_value'] = self.attr_value.to_alipay_dict()
@@ -48,6 +61,8 @@ class ItemSkuAttrVO(object):
         o = ItemSkuAttrVO()
         if 'attr_key' in d:
             o.attr_key = d['attr_key']
+        if 'attr_type' in d:
+            o.attr_type = d['attr_type']
         if 'attr_value' in d:
             o.attr_value = d['attr_value']
         return o
