@@ -9,6 +9,7 @@ class OpenAccessCodeDTO(object):
 
     def __init__(self):
         self._access_code = None
+        self._auth_code = None
         self._expire_time = None
 
     @property
@@ -19,6 +20,13 @@ class OpenAccessCodeDTO(object):
     def access_code(self, value):
         self._access_code = value
     @property
+    def auth_code(self):
+        return self._auth_code
+
+    @auth_code.setter
+    def auth_code(self, value):
+        self._auth_code = value
+    @property
     def expire_time(self):
         return self._expire_time
 
@@ -34,6 +42,11 @@ class OpenAccessCodeDTO(object):
                 params['access_code'] = self.access_code.to_alipay_dict()
             else:
                 params['access_code'] = self.access_code
+        if self.auth_code:
+            if hasattr(self.auth_code, 'to_alipay_dict'):
+                params['auth_code'] = self.auth_code.to_alipay_dict()
+            else:
+                params['auth_code'] = self.auth_code
         if self.expire_time:
             if hasattr(self.expire_time, 'to_alipay_dict'):
                 params['expire_time'] = self.expire_time.to_alipay_dict()
@@ -48,6 +61,8 @@ class OpenAccessCodeDTO(object):
         o = OpenAccessCodeDTO()
         if 'access_code' in d:
             o.access_code = d['access_code']
+        if 'auth_code' in d:
+            o.auth_code = d['auth_code']
         if 'expire_time' in d:
             o.expire_time = d['expire_time']
         return o
