@@ -9,6 +9,7 @@ class PriceInfoModifyDTO(object):
 
     def __init__(self):
         self._order_price = None
+        self._real_order_price = None
 
     @property
     def order_price(self):
@@ -17,6 +18,13 @@ class PriceInfoModifyDTO(object):
     @order_price.setter
     def order_price(self, value):
         self._order_price = value
+    @property
+    def real_order_price(self):
+        return self._real_order_price
+
+    @real_order_price.setter
+    def real_order_price(self, value):
+        self._real_order_price = value
 
 
     def to_alipay_dict(self):
@@ -26,6 +34,11 @@ class PriceInfoModifyDTO(object):
                 params['order_price'] = self.order_price.to_alipay_dict()
             else:
                 params['order_price'] = self.order_price
+        if self.real_order_price:
+            if hasattr(self.real_order_price, 'to_alipay_dict'):
+                params['real_order_price'] = self.real_order_price.to_alipay_dict()
+            else:
+                params['real_order_price'] = self.real_order_price
         return params
 
     @staticmethod
@@ -35,6 +48,8 @@ class PriceInfoModifyDTO(object):
         o = PriceInfoModifyDTO()
         if 'order_price' in d:
             o.order_price = d['order_price']
+        if 'real_order_price' in d:
+            o.real_order_price = d['real_order_price']
         return o
 
 
