@@ -10,6 +10,7 @@ class PromotePageProperty(object):
     def __init__(self):
         self._key = None
         self._name = None
+        self._type = None
 
     @property
     def key(self):
@@ -25,6 +26,13 @@ class PromotePageProperty(object):
     @name.setter
     def name(self, value):
         self._name = value
+    @property
+    def type(self):
+        return self._type
+
+    @type.setter
+    def type(self, value):
+        self._type = value
 
 
     def to_alipay_dict(self):
@@ -39,6 +47,11 @@ class PromotePageProperty(object):
                 params['name'] = self.name.to_alipay_dict()
             else:
                 params['name'] = self.name
+        if self.type:
+            if hasattr(self.type, 'to_alipay_dict'):
+                params['type'] = self.type.to_alipay_dict()
+            else:
+                params['type'] = self.type
         return params
 
     @staticmethod
@@ -50,6 +63,8 @@ class PromotePageProperty(object):
             o.key = d['key']
         if 'name' in d:
             o.name = d['name']
+        if 'type' in d:
+            o.type = d['type']
         return o
 
 
