@@ -11,8 +11,10 @@ class VoucherSaleModeInfo(object):
     def __init__(self):
         self._fund_custody_mode = None
         self._overdue_refundable = None
+        self._overdue_refundable_need_confirm = None
         self._payee_pid = None
         self._refundable = None
+        self._refundable_need_confirm = None
         self._sale_amount = None
         self._settle_info = None
 
@@ -31,6 +33,13 @@ class VoucherSaleModeInfo(object):
     def overdue_refundable(self, value):
         self._overdue_refundable = value
     @property
+    def overdue_refundable_need_confirm(self):
+        return self._overdue_refundable_need_confirm
+
+    @overdue_refundable_need_confirm.setter
+    def overdue_refundable_need_confirm(self, value):
+        self._overdue_refundable_need_confirm = value
+    @property
     def payee_pid(self):
         return self._payee_pid
 
@@ -45,6 +54,13 @@ class VoucherSaleModeInfo(object):
     def refundable(self, value):
         self._refundable = value
     @property
+    def refundable_need_confirm(self):
+        return self._refundable_need_confirm
+
+    @refundable_need_confirm.setter
+    def refundable_need_confirm(self, value):
+        self._refundable_need_confirm = value
+    @property
     def sale_amount(self):
         return self._sale_amount
 
@@ -75,6 +91,11 @@ class VoucherSaleModeInfo(object):
                 params['overdue_refundable'] = self.overdue_refundable.to_alipay_dict()
             else:
                 params['overdue_refundable'] = self.overdue_refundable
+        if self.overdue_refundable_need_confirm:
+            if hasattr(self.overdue_refundable_need_confirm, 'to_alipay_dict'):
+                params['overdue_refundable_need_confirm'] = self.overdue_refundable_need_confirm.to_alipay_dict()
+            else:
+                params['overdue_refundable_need_confirm'] = self.overdue_refundable_need_confirm
         if self.payee_pid:
             if hasattr(self.payee_pid, 'to_alipay_dict'):
                 params['payee_pid'] = self.payee_pid.to_alipay_dict()
@@ -85,6 +106,11 @@ class VoucherSaleModeInfo(object):
                 params['refundable'] = self.refundable.to_alipay_dict()
             else:
                 params['refundable'] = self.refundable
+        if self.refundable_need_confirm:
+            if hasattr(self.refundable_need_confirm, 'to_alipay_dict'):
+                params['refundable_need_confirm'] = self.refundable_need_confirm.to_alipay_dict()
+            else:
+                params['refundable_need_confirm'] = self.refundable_need_confirm
         if self.sale_amount:
             if hasattr(self.sale_amount, 'to_alipay_dict'):
                 params['sale_amount'] = self.sale_amount.to_alipay_dict()
@@ -106,10 +132,14 @@ class VoucherSaleModeInfo(object):
             o.fund_custody_mode = d['fund_custody_mode']
         if 'overdue_refundable' in d:
             o.overdue_refundable = d['overdue_refundable']
+        if 'overdue_refundable_need_confirm' in d:
+            o.overdue_refundable_need_confirm = d['overdue_refundable_need_confirm']
         if 'payee_pid' in d:
             o.payee_pid = d['payee_pid']
         if 'refundable' in d:
             o.refundable = d['refundable']
+        if 'refundable_need_confirm' in d:
+            o.refundable_need_confirm = d['refundable_need_confirm']
         if 'sale_amount' in d:
             o.sale_amount = d['sale_amount']
         if 'settle_info' in d:
