@@ -9,7 +9,9 @@ class ZhimaCreditEpAcceptanceAccessQueryModel(object):
 
     def __init__(self):
         self._ep_cert_no = None
+        self._open_id = None
         self._scene_code = None
+        self._user_id = None
 
     @property
     def ep_cert_no(self):
@@ -19,12 +21,26 @@ class ZhimaCreditEpAcceptanceAccessQueryModel(object):
     def ep_cert_no(self, value):
         self._ep_cert_no = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def scene_code(self):
         return self._scene_code
 
     @scene_code.setter
     def scene_code(self, value):
         self._scene_code = value
+    @property
+    def user_id(self):
+        return self._user_id
+
+    @user_id.setter
+    def user_id(self, value):
+        self._user_id = value
 
 
     def to_alipay_dict(self):
@@ -34,11 +50,21 @@ class ZhimaCreditEpAcceptanceAccessQueryModel(object):
                 params['ep_cert_no'] = self.ep_cert_no.to_alipay_dict()
             else:
                 params['ep_cert_no'] = self.ep_cert_no
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.scene_code:
             if hasattr(self.scene_code, 'to_alipay_dict'):
                 params['scene_code'] = self.scene_code.to_alipay_dict()
             else:
                 params['scene_code'] = self.scene_code
+        if self.user_id:
+            if hasattr(self.user_id, 'to_alipay_dict'):
+                params['user_id'] = self.user_id.to_alipay_dict()
+            else:
+                params['user_id'] = self.user_id
         return params
 
     @staticmethod
@@ -48,8 +74,12 @@ class ZhimaCreditEpAcceptanceAccessQueryModel(object):
         o = ZhimaCreditEpAcceptanceAccessQueryModel()
         if 'ep_cert_no' in d:
             o.ep_cert_no = d['ep_cert_no']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'scene_code' in d:
             o.scene_code = d['scene_code']
+        if 'user_id' in d:
+            o.user_id = d['user_id']
         return o
 
 
