@@ -10,6 +10,7 @@ class ZhimaCreditPeVisaReportQueryModel(object):
     def __init__(self):
         self._include_file = None
         self._open_id = None
+        self._passport_no = None
         self._scene_code = None
         self._user_id = None
 
@@ -28,6 +29,13 @@ class ZhimaCreditPeVisaReportQueryModel(object):
     def open_id(self, value):
         self._open_id = value
     @property
+    def passport_no(self):
+        return self._passport_no
+
+    @passport_no.setter
+    def passport_no(self, value):
+        self._passport_no = value
+    @property
     def scene_code(self):
         return self._scene_code
 
@@ -55,6 +63,11 @@ class ZhimaCreditPeVisaReportQueryModel(object):
                 params['open_id'] = self.open_id.to_alipay_dict()
             else:
                 params['open_id'] = self.open_id
+        if self.passport_no:
+            if hasattr(self.passport_no, 'to_alipay_dict'):
+                params['passport_no'] = self.passport_no.to_alipay_dict()
+            else:
+                params['passport_no'] = self.passport_no
         if self.scene_code:
             if hasattr(self.scene_code, 'to_alipay_dict'):
                 params['scene_code'] = self.scene_code.to_alipay_dict()
@@ -76,6 +89,8 @@ class ZhimaCreditPeVisaReportQueryModel(object):
             o.include_file = d['include_file']
         if 'open_id' in d:
             o.open_id = d['open_id']
+        if 'passport_no' in d:
+            o.passport_no = d['passport_no']
         if 'scene_code' in d:
             o.scene_code = d['scene_code']
         if 'user_id' in d:
