@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.response.AlipayResponse import AlipayResponse
+from alipay.aop.api.domain.ToBDiscountCustomerServiceInfo import ToBDiscountCustomerServiceInfo
 
 
 class AlipayCommerceAcommunicationDiscountPhonePayResponse(AlipayResponse):
@@ -11,6 +12,7 @@ class AlipayCommerceAcommunicationDiscountPhonePayResponse(AlipayResponse):
         super(AlipayCommerceAcommunicationDiscountPhonePayResponse, self).__init__()
         self._alipay_biz_no = None
         self._alipay_trade_no = None
+        self._customer_service_info = None
 
     @property
     def alipay_biz_no(self):
@@ -26,6 +28,16 @@ class AlipayCommerceAcommunicationDiscountPhonePayResponse(AlipayResponse):
     @alipay_trade_no.setter
     def alipay_trade_no(self, value):
         self._alipay_trade_no = value
+    @property
+    def customer_service_info(self):
+        return self._customer_service_info
+
+    @customer_service_info.setter
+    def customer_service_info(self, value):
+        if isinstance(value, ToBDiscountCustomerServiceInfo):
+            self._customer_service_info = value
+        else:
+            self._customer_service_info = ToBDiscountCustomerServiceInfo.from_alipay_dict(value)
 
     def parse_response_content(self, response_content):
         response = super(AlipayCommerceAcommunicationDiscountPhonePayResponse, self).parse_response_content(response_content)
@@ -33,3 +45,5 @@ class AlipayCommerceAcommunicationDiscountPhonePayResponse(AlipayResponse):
             self.alipay_biz_no = response['alipay_biz_no']
         if 'alipay_trade_no' in response:
             self.alipay_trade_no = response['alipay_trade_no']
+        if 'customer_service_info' in response:
+            self.customer_service_info = response['customer_service_info']
