@@ -9,10 +9,18 @@ class AlipayCommerceEcRecyclinginvoiceCompanyclerkCreateResponse(AlipayResponse)
 
     def __init__(self):
         super(AlipayCommerceEcRecyclinginvoiceCompanyclerkCreateResponse, self).__init__()
+        self._clerk_auth_url = None
         self._company_clerk_id = None
         self._out_clerk_id = None
 
     @property
+    def clerk_auth_url(self):
+        return self._clerk_auth_url
+
+    @clerk_auth_url.setter
+    def clerk_auth_url(self, value):
+        self._clerk_auth_url = value
+    @property
     def company_clerk_id(self):
         return self._company_clerk_id
 
@@ -29,6 +37,8 @@ class AlipayCommerceEcRecyclinginvoiceCompanyclerkCreateResponse(AlipayResponse)
 
     def parse_response_content(self, response_content):
         response = super(AlipayCommerceEcRecyclinginvoiceCompanyclerkCreateResponse, self).parse_response_content(response_content)
+        if 'clerk_auth_url' in response:
+            self.clerk_auth_url = response['clerk_auth_url']
         if 'company_clerk_id' in response:
             self.company_clerk_id = response['company_clerk_id']
         if 'out_clerk_id' in response:
