@@ -12,6 +12,7 @@ class AlipayFundTaxbillSigncodeCreateResponse(AlipayResponse):
         self._biz_scene = None
         self._product_code = None
         self._sign_code = None
+        self._sign_code_type = None
 
     @property
     def biz_scene(self):
@@ -34,6 +35,13 @@ class AlipayFundTaxbillSigncodeCreateResponse(AlipayResponse):
     @sign_code.setter
     def sign_code(self, value):
         self._sign_code = value
+    @property
+    def sign_code_type(self):
+        return self._sign_code_type
+
+    @sign_code_type.setter
+    def sign_code_type(self, value):
+        self._sign_code_type = value
 
     def parse_response_content(self, response_content):
         response = super(AlipayFundTaxbillSigncodeCreateResponse, self).parse_response_content(response_content)
@@ -43,3 +51,5 @@ class AlipayFundTaxbillSigncodeCreateResponse(AlipayResponse):
             self.product_code = response['product_code']
         if 'sign_code' in response:
             self.sign_code = response['sign_code']
+        if 'sign_code_type' in response:
+            self.sign_code_type = response['sign_code_type']
