@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.response.AlipayResponse import AlipayResponse
+from alipay.aop.api.domain.BenefitAccountFsFundInfoDTO import BenefitAccountFsFundInfoDTO
 
 
 class AlipayMarketingBenefitaccountAccountRefundResponse(AlipayResponse):
@@ -10,6 +11,7 @@ class AlipayMarketingBenefitaccountAccountRefundResponse(AlipayResponse):
     def __init__(self):
         super(AlipayMarketingBenefitaccountAccountRefundResponse, self).__init__()
         self._amount = None
+        self._fund_infos = None
         self._order_no = None
 
     @property
@@ -20,6 +22,16 @@ class AlipayMarketingBenefitaccountAccountRefundResponse(AlipayResponse):
     def amount(self, value):
         self._amount = value
     @property
+    def fund_infos(self):
+        return self._fund_infos
+
+    @fund_infos.setter
+    def fund_infos(self, value):
+        if isinstance(value, BenefitAccountFsFundInfoDTO):
+            self._fund_infos = value
+        else:
+            self._fund_infos = BenefitAccountFsFundInfoDTO.from_alipay_dict(value)
+    @property
     def order_no(self):
         return self._order_no
 
@@ -31,5 +43,7 @@ class AlipayMarketingBenefitaccountAccountRefundResponse(AlipayResponse):
         response = super(AlipayMarketingBenefitaccountAccountRefundResponse, self).parse_response_content(response_content)
         if 'amount' in response:
             self.amount = response['amount']
+        if 'fund_infos' in response:
+            self.fund_infos = response['fund_infos']
         if 'order_no' in response:
             self.order_no = response['order_no']
