@@ -3,17 +3,32 @@
 import json
 
 from alipay.aop.api.response.AlipayResponse import AlipayResponse
+from alipay.aop.api.domain.WatchAppInfo import WatchAppInfo
 
 
 class AlipayPayAppPocketmoneyAuthQueryResponse(AlipayResponse):
 
     def __init__(self):
         super(AlipayPayAppPocketmoneyAuthQueryResponse, self).__init__()
+        self._app_infos = None
         self._auth_result = None
         self._change_code_id = None
         self._vendor_parent_id = None
 
     @property
+    def app_infos(self):
+        return self._app_infos
+
+    @app_infos.setter
+    def app_infos(self, value):
+        if isinstance(value, list):
+            self._app_infos = list()
+            for i in value:
+                if isinstance(i, WatchAppInfo):
+                    self._app_infos.append(i)
+                else:
+                    self._app_infos.append(WatchAppInfo.from_alipay_dict(i))
+    @property
     def auth_result(self):
         return self._auth_result
 
@@ -37,6 +52,8 @@ class AlipayPayAppPocketmoneyAuthQueryResponse(AlipayResponse):
 
     def parse_response_content(self, response_content):
         response = super(AlipayPayAppPocketmoneyAuthQueryResponse, self).parse_response_content(response_content)
+        if 'app_infos' in response:
+            self.app_infos = response['app_infos']
         if 'auth_result' in response:
             self.auth_result = response['auth_result']
         if 'change_code_id' in response:
