@@ -11,6 +11,7 @@ class AlipayTradeCreditGoodsConfirmResponse(AlipayResponse):
         super(AlipayTradeCreditGoodsConfirmResponse, self).__init__()
         self._credit_biz_order_id = None
         self._credit_confirm_receive_goods_time = None
+        self._credit_task_first_exec_time = None
 
     @property
     def credit_biz_order_id(self):
@@ -26,6 +27,13 @@ class AlipayTradeCreditGoodsConfirmResponse(AlipayResponse):
     @credit_confirm_receive_goods_time.setter
     def credit_confirm_receive_goods_time(self, value):
         self._credit_confirm_receive_goods_time = value
+    @property
+    def credit_task_first_exec_time(self):
+        return self._credit_task_first_exec_time
+
+    @credit_task_first_exec_time.setter
+    def credit_task_first_exec_time(self, value):
+        self._credit_task_first_exec_time = value
 
     def parse_response_content(self, response_content):
         response = super(AlipayTradeCreditGoodsConfirmResponse, self).parse_response_content(response_content)
@@ -33,3 +41,5 @@ class AlipayTradeCreditGoodsConfirmResponse(AlipayResponse):
             self.credit_biz_order_id = response['credit_biz_order_id']
         if 'credit_confirm_receive_goods_time' in response:
             self.credit_confirm_receive_goods_time = response['credit_confirm_receive_goods_time']
+        if 'credit_task_first_exec_time' in response:
+            self.credit_task_first_exec_time = response['credit_task_first_exec_time']
