@@ -10,6 +10,7 @@ class AlipayUserAuthUserinfoApplyResponse(AlipayResponse):
     def __init__(self):
         super(AlipayUserAuthUserinfoApplyResponse, self).__init__()
         self._auth_code = None
+        self._open_id = None
         self._user_id = None
 
     @property
@@ -20,6 +21,13 @@ class AlipayUserAuthUserinfoApplyResponse(AlipayResponse):
     def auth_code(self, value):
         self._auth_code = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def user_id(self):
         return self._user_id
 
@@ -31,5 +39,7 @@ class AlipayUserAuthUserinfoApplyResponse(AlipayResponse):
         response = super(AlipayUserAuthUserinfoApplyResponse, self).parse_response_content(response_content)
         if 'auth_code' in response:
             self.auth_code = response['auth_code']
+        if 'open_id' in response:
+            self.open_id = response['open_id']
         if 'user_id' in response:
             self.user_id = response['user_id']
