@@ -11,6 +11,7 @@ class DatadigitalFincloudGeneralsaasFaceCheckInitializeResponse(AlipayResponse):
         super(DatadigitalFincloudGeneralsaasFaceCheckInitializeResponse, self).__init__()
         self._certify_id = None
         self._page_url = None
+        self._web_url = None
 
     @property
     def certify_id(self):
@@ -26,6 +27,13 @@ class DatadigitalFincloudGeneralsaasFaceCheckInitializeResponse(AlipayResponse):
     @page_url.setter
     def page_url(self, value):
         self._page_url = value
+    @property
+    def web_url(self):
+        return self._web_url
+
+    @web_url.setter
+    def web_url(self, value):
+        self._web_url = value
 
     def parse_response_content(self, response_content):
         response = super(DatadigitalFincloudGeneralsaasFaceCheckInitializeResponse, self).parse_response_content(response_content)
@@ -33,3 +41,5 @@ class DatadigitalFincloudGeneralsaasFaceCheckInitializeResponse(AlipayResponse):
             self.certify_id = response['certify_id']
         if 'page_url' in response:
             self.page_url = response['page_url']
+        if 'web_url' in response:
+            self.web_url = response['web_url']
