@@ -10,6 +10,7 @@ class ZhimaCreditPayafteruseCreditbizorderFinishResponse(AlipayResponse):
     def __init__(self):
         super(ZhimaCreditPayafteruseCreditbizorderFinishResponse, self).__init__()
         self._credit_biz_order_id = None
+        self._order_status = None
         self._out_request_no = None
 
     @property
@@ -20,6 +21,13 @@ class ZhimaCreditPayafteruseCreditbizorderFinishResponse(AlipayResponse):
     def credit_biz_order_id(self, value):
         self._credit_biz_order_id = value
     @property
+    def order_status(self):
+        return self._order_status
+
+    @order_status.setter
+    def order_status(self, value):
+        self._order_status = value
+    @property
     def out_request_no(self):
         return self._out_request_no
 
@@ -31,5 +39,7 @@ class ZhimaCreditPayafteruseCreditbizorderFinishResponse(AlipayResponse):
         response = super(ZhimaCreditPayafteruseCreditbizorderFinishResponse, self).parse_response_content(response_content)
         if 'credit_biz_order_id' in response:
             self.credit_biz_order_id = response['credit_biz_order_id']
+        if 'order_status' in response:
+            self.order_status = response['order_status']
         if 'out_request_no' in response:
             self.out_request_no = response['out_request_no']
